
# Titulo de la Sintaxis: 
# Control prenatal

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analsis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para calcular estadisticos para variables dicotomicas 
srvyr_prop <- function(design, x) {
  
  design %>% 
    summarise(
      props = survey_mean({{ x }},
                          proportion = TRUE,   
                          vartype = c("se", "ci", "cv"),
                          na.rm = T) * 100, 
      deff = survey_mean({{ x }},  
                         deff = "replace",
                         na.rm = T),
      Num = sum({{ x }}, na.rm = TRUE),
      Deno = sum(!is.na({{ x }}))) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Props = props, 
      EE    = props_se, 
      LI    = props_low, 
      LS    = props_upp, 
      CV    = props_cv,
      Deff  = deff_deff,
      Num   = Num, 
      Deno  = Deno
    )  
  
}

# Funcion para calcular estadisticos para variables dicotomicas 
# por desagregacion 
srvyr_prop_by <- function(design, x, by) {
  
  design %>%
    group_by({{ by }}) %>%
    summarise(
      props = survey_mean({{ x }},
                          proportion = TRUE,   
                          vartype = c("se", "ci", "cv"),
                          na.rm = T) * 100, 
      deff = survey_mean({{ x }},  
                         deff = "replace",
                         na.rm = T),
      Num = sum({{ x }}, na.rm = TRUE),
      Deno = sum(!is.na({{ x }}))) %>%
    mutate(desag = {{ by }}) %>%
    select(
      Desag = desag,
      Props = props, 
      EE    = props_se, 
      LI    = props_low, 
      LS    = props_upp, 
      CV    = props_cv,
      Deff  = deff_deff,
      Num   = Num, 
      Deno  = Deno
    )  
  
}

# Funcion para calcular promedios con sus estadisticos  
srvyr_mean <- function(design, x) {
  
  design %>% 
    filter(!is.na({{ x }})) %>% 
    summarise(
      mean = survey_mean({{ x }},
                         vartype = c("se", "ci"),
                         deff = "replace",
                         na.rm = T),
      cv = survey_mean({{ x }},
                       vartype = c("cv"),
                       na.rm = T)*100,
      n = unweighted(n())) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Media = mean,
      EE    = mean_se,
      LI    = mean_low,
      LS    = mean_upp,
      CV    = cv_cv,
      Deff  = mean_deff,
      n     = n
    )
  
}

# Funcion para calcular promedios con sus estadisticos  
# por desagregacion 
srvyr_mean_by <- function(design, x, by) {
  
  design %>% 
    filter(!is.na({{ x }})) %>% 
    group_by({{ by }}) %>%
    summarise(
      mean = survey_mean({{ x }},
                         vartype = c("se", "ci"),
                         deff = "replace",
                         na.rm = T),
      cv = survey_mean({{ x }},
                       vartype = c("cv"),
                       na.rm = T)*100,
      n = unweighted(n())) %>%
    mutate(desag = {{ by }}) %>%
    select(
      Desag = desag,
      Media = mean,
      EE    = mean_se,
      LI    = mean_low,
      LS    = mean_upp,
      CV    = cv_cv,
      Deff  = mean_deff,
      n     = n
    )
  
}

#==============================================================================#
####                          Carga de base de datos                        ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion import 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# df_f1_personas <- import("C:/ENDI/Data/f1_personas.rds")

# Sugerencias:

# Es probable que R no reconozca las rutas de archivos que comienzan con barras 
# inclinadas dobles (p. ej., “//…”) y produzcan un error. Considere mover 
# su trabajo a una unidad "con nombre" o "con letras" (p. ej., "C:" o "D:").

# Base Personas 
df_f1_personas <- import("")
df_f1_personas <- as_tibble(df_f1_personas) 
df_f1_personas

# Base MEF 
df_f2_mef <- import("")
df_f2_mef <- as_tibble(df_f2_mef) 
df_f2_mef

# Base Salud en la Ninez 
df_f2_salud_ninez <- import("")
df_f2_salud_ninez <- as_tibble(df_f2_salud_ninez) 
df_f2_salud_ninez

# Diccionario de variables 
# Cargar el archivo: Diccionario_ENDI.xlsx con la hoja ya especificada   

# MEF
dicc_f2_mef <- import("/Diccionario_ENDI.xlsx",
                      which = "f2_mef")
dicc_f2_mef <- as_tibble(dicc_f2_mef)   
dicc_f2_mef

# Salud en la Ninez 
dicc_f2_sani <- import("/Diccionario_ENDI.xlsx",
                       which = "f2_salud_ninez")
dicc_f2_sani <- as_tibble(dicc_f2_sani)   
dicc_f2_sani

#==============================================================================#
####           Calculo de variables necesarias para el indicador            ####
#==============================================================================#

#------------------------------------------------------------------------------#
# Se procede a cambiar la base de mef de ancho a largo en funcion del numero 
# de hijos
#------------------------------------------------------------------------------#

# Nueva base con las variables de los hijos de las mefs
df_f2_hijos <- df_f2_mef %>% 
  select(starts_with("id"), starts_with("f2_s2_235_cod_"), 
         starts_with("f2_s2_235_a_"), starts_with("f2_s2_235_b_dia_"), 
         starts_with("f2_s2_235_b_mes_"), starts_with("f2_s2_235_b_anio_")) 

# Cambio de la base de ancho a largo 
df_f2_hijos_long <- df_f2_hijos %>% 
  pivot_longer(
    cols = starts_with("f2_s2_235_"),
    names_to = c(".value", "ord_hijo"),
    names_pattern = "([A-Za-z]+)_([0-9]+)"
  ) 

df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(across(c(cod, dia, mes, anio), as.character))

df_f2_hijos_long <- df_f2_hijos_long %>% 
  rename(sexo = a)

rm(df_f2_hijos, df_f2_mef)

# Creacion de variables con dos digitos  
df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(cod = case_when(
    nchar(cod) == 1 ~ paste0("0", cod),
    TRUE ~ cod
  )) %>% 
  mutate(ord_hijo = case_when(
    nchar(ord_hijo) == 1 ~ paste0("0", ord_hijo),
    TRUE ~ ord_hijo
  ))

# Creacion de identificadores 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(id_hijo_ord = case_when(
    !is.na(cod) ~ paste0(id_mef, cod, ord_hijo),
    TRUE ~ NA_character_
  ))

# Mantengo la base de los hijos registrados 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  filter(!is.na(id_hijo_ord))

# Mantengo variables a utilizar 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  select(id_hijo_ord, dia, mes, anio, sexo)

#------------------------------------------------------------------------------#
# Join - Base de hijos seccion 2 y base de salud de la ninez 
#------------------------------------------------------------------------------#

# Join 
df_f2_salud_ninez_new <- df_f2_salud_ninez %>% 
  inner_join(df_f2_hijos_long, by = c("id_hijo_ord")) 

rm(df_f2_hijos_long, df_f2_salud_ninez)

#------------------------------------------------------------------------------#
# Join 
#------------------------------------------------------------------------------#

# Variables de desagregacion a partir del identificador de personas  
df_f1_personas_new <- df_f1_personas %>% 
  select(id_per, parr_pri, etnia, quintil, pobreza, nbi_1)

# Variables de desagregacion a partir del identificador de mef  
df_f1_mef <- df_f1_personas %>% 
  select(id_mef, parr_pri, etnia, quintil, pobreza, nbi_1) %>% 
  rename(parr_pri_mef = parr_pri,
         etnia_mef = etnia,
         quintil_mef = quintil,
         pobreza_mef = pobreza,
         nbi_1_mef = nbi_1)

# Join 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  left_join(df_f1_personas_new, by = c("id_per"))

df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  left_join(df_f1_mef, by = c("id_mef"))

# Recuperacion de informacion de las hijas/os por medio de la informacion de la 
# madre, esto para las hijas/os que no son miembros de hogar o fallecidas/os

df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(parr_pri = coalesce(parr_pri, parr_pri_mef),
         etnia = coalesce(etnia, etnia_mef),
         quintil = coalesce(quintil, quintil_mef),
         pobreza = coalesce(pobreza, pobreza_mef),
         nbi_1 = coalesce(nbi_1, nbi_1_mef))

rm(df_f1_personas, df_f1_personas_new, df_f1_mef)

#==============================================================================#
####         Calculo de los indicadores sobre controles prenatales          ####
#==============================================================================#

# Estimacion de la edad en dias -----------------------------------------------#

df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(dob = paste(anio, mes, dia)) %>%
  mutate(dov = paste(fecha_anio, fecha_mes, fecha_dia)) %>%
  mutate(dob = as_date(dob)) %>%   
  mutate(dov = as_date(dov)) %>%  
  mutate(edaddias = (dob %--% dov) / days(1)) 

df_f2_salud_ninez_new %>%
  descr(edaddias, 
        stats = c("common")) 

# Controles prenatales --------------------------------------------------------#

# Revision 
df_f2_salud_ninez_new %>%
  descr(f2_s4b_406, 
        stats = c("common")) 

# Indicador (menores de 5 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(c_prenatales = f2_s4b_406)

df_f2_salud_ninez_new %>%
  descr(c_prenatales,
        stats = c("common"))

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(c_prenatales2 = case_when( 
    edaddias < 731 & !is.na(edaddias) ~ f2_s4b_406,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>%
  descr(c_prenatales2,
        stats = c("common"))

# Al menos 5 controles prenatales ----------------------------------------------#

df_f2_salud_ninez_new %>% 
  descr(f2_s4b_406, 
        stats = c("common"))

# Indicador (menores de 5 anios) 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(control5_5 = case_when(
    f2_s4b_406 >= 5 & !is.na(f2_s4b_406) ~ 1,
    f2_s4b_406 < 5 & !is.na(f2_s4b_406) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(control5_5, cumul = F, report.nas = F)

# Indicador (menores de 2 anios) 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(control5_2 = case_when(
    f2_s4b_406 >= 5 & !is.na(f2_s4b_406) &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_406 < 5 & !is.na(f2_s4b_406) &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(control5_2, cumul = F, report.nas = F)

# Consumo de hierro y acido folico (durante el embarazo) ----------------------#

# Acido folico  
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_409_a, cumul = F, report.nas = F)

# Hierro
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_410_a, cumul = F, report.nas = F)

# Indicador (menores de 5 anios) 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(consumo_ha = case_when(
    f2_s4b_409_a == 1 & f2_s4b_410_a == 1 ~ 1,
    !is.na(f2_s4b_409_a) & !is.na(f2_s4b_410_a) ~ 0,
    TRUE ~ NA_real_
  )) 

df_f2_salud_ninez_new %>% 
  freq(consumo_ha, cumul = F, report.nas = F)

# Indicador (menores de 2 anios) 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(consumo_ha_2 = case_when(
    f2_s4b_409_a == 1 & f2_s4b_410_a == 1 & 
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    !is.na(f2_s4b_409_a) & !is.na(f2_s4b_410_a) &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  )) 

df_f2_salud_ninez_new %>% 
  freq(consumo_ha_2, cumul = F, report.nas = F)

# Examen de VIH (antes de la semana 20) ---------------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_415, cumul = F, report.nas = F)

# Indicador (menores de 5 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(vih_ant = case_when(
    f2_s4b_415 == 1 ~ 1,
    f2_s4b_415 == 2 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(vih_ant, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(vih_ant_2 = case_when(
    f2_s4b_415 == 1 &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_415 == 2 &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(vih_ant_2, cumul = F, report.nas = F)

# Examen de VIH (despues de la semana 20) -------------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_416, cumul = F, report.nas = F)

# Indicador (menores de 5 anios) 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(vih_des = case_when(
    f2_s4b_416 == 1 ~ 1,
    f2_s4b_416 == 2 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(vih_des, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(vih_des_2 = case_when(
    f2_s4b_416 == 1 &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_416 == 2 &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(vih_des_2, cumul = F, report.nas = F)

# Examenes de VIH (durante el embarazo) ---------------------------------------#

# Indicador (menores de 5 anios) 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(vih_dur = case_when(
    (f2_s4b_415 == 1 | f2_s4b_416 == 1) ~ 1,
    (f2_s4b_415 == 2 | f2_s4b_416 == 2) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(vih_dur, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(vih_dur_2 = case_when(
    (f2_s4b_415 == 1 | f2_s4b_416 == 1) &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    (f2_s4b_415 == 2 | f2_s4b_416 == 2) &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(vih_dur_2, cumul = F, report.nas = F)

# Examenes de orina (antes de la semana 20) -----------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_420_a, cumul = F, report.nas = F)

# Indicador (menores de 5 anios) 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(ori_ant = case_when(
    f2_s4b_420_a == 1 ~ 1,
    f2_s4b_420_a == 2 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(ori_ant, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(ori_ant_2 = case_when(
    f2_s4b_420_a == 1 &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_420_a == 2 &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(ori_ant_2, cumul = F, report.nas = F)

# Examenes de orina (despues de la semana 20) ---------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_421_a, cumul = F, report.nas = F)

# Indicador (menores de 5 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(ori_des = case_when(
    f2_s4b_421_a == 1 ~ 1,
    f2_s4b_421_a == 2 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(ori_des, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(ori_des_2 = case_when(
    f2_s4b_421_a == 1 &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_421_a == 2 &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(ori_des_2, cumul = F, report.nas = F)

# Examenes de orina (durante el embarazo) -------------------------------------#

# Indicador (menores de 5 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(ori_dur = case_when(
    (f2_s4b_420_a == 1 | f2_s4b_421_a == 1) ~ 1,
    (f2_s4b_420_a == 2 | f2_s4b_421_a == 2) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(ori_dur, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(ori_dur_2 = case_when(
    (f2_s4b_420_a == 1 | f2_s4b_421_a == 1) &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    (f2_s4b_420_a == 2 | f2_s4b_421_a == 2) & 
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(ori_dur_2, cumul = F, report.nas = F)

# Examenes de TORCHs (antes de la semana 20) ----------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_422_a, cumul = F, report.nas = F)

# Indicador
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(torchs_ant = case_when(
    f2_s4b_422_a == 1 ~ 1,
    f2_s4b_422_a == 2 ~ 0,
    TRUE ~ NA_real_ 
  ))

df_f2_salud_ninez_new %>% 
  freq(torchs_ant, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(torchs_ant_2 = case_when(
    f2_s4b_422_a == 1 &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_422_a == 2 &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(torchs_ant_2, cumul = F, report.nas = F)

# Examenes de TORCHs (despues de la semana 20) --------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_423_a, cumul = F, report.nas = F)

# Indicador
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(torchs_des = case_when(
    f2_s4b_423_a == 1 ~ 1,
    f2_s4b_423_a == 2 ~ 0,
    TRUE ~ NA_real_ 
  ))

df_f2_salud_ninez_new %>% 
  freq(torchs_des, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(torchs_des_2 = case_when(
    f2_s4b_423_a == 1 &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_423_a == 2 &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(torchs_des_2, cumul = F, report.nas = F)

# Examenes de TORCHs (durante el embarazo) ------------------------------------#

# Indicador
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(torchs_dur = case_when(
    (f2_s4b_422_a == 1 |  f2_s4b_423_a == 1) ~ 1,
    (f2_s4b_422_a == 2 |  f2_s4b_423_a == 2) ~ 0,
    TRUE ~ NA_real_ 
  ))

df_f2_salud_ninez_new %>% 
  freq(torchs_dur, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(torchs_dur_2 = case_when(
    (f2_s4b_422_a == 1 |  f2_s4b_423_a == 1) &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    (f2_s4b_422_a == 2 |  f2_s4b_423_a == 2) &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_ 
  ))

df_f2_salud_ninez_new %>% 
  freq(torchs_dur_2, cumul = F, report.nas = F)

# Examenes de VIH, Orina y TORCHs (durante el embarazo) -----------------------#

# Indicador (menores de 5 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(vot_dur = case_when(
    (f2_s4b_415 == 1 | f2_s4b_416 == 1) &
      (f2_s4b_420_a == 1 | f2_s4b_421_a == 1) &
      (f2_s4b_422_a == 1 |  f2_s4b_423_a == 1) ~ 1,
    (!is.na(f2_s4b_415) & f2_s4b_415 != 88) |
      (!is.na(f2_s4b_416) & f2_s4b_416 != 88) |
      (!is.na(f2_s4b_420_a) & f2_s4b_420_a != 88) |
      (!is.na(f2_s4b_421_a) & f2_s4b_421_a != 88) |
      (!is.na(f2_s4b_422_a) & f2_s4b_422_a != 88) |
      (!is.na(f2_s4b_423_a) & f2_s4b_423_a != 88) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(vot_dur, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(vot_dur_2 = case_when(
    (f2_s4b_415 == 1 | f2_s4b_416 == 1) &
      (f2_s4b_420_a == 1 | f2_s4b_421_a == 1) &
      (f2_s4b_422_a == 1 |  f2_s4b_423_a == 1) &
      (edaddias < 731 & !is.na(edaddias)) ~ 1,
    ((!is.na(f2_s4b_415) & f2_s4b_415 != 88) |
       (!is.na(f2_s4b_416) & f2_s4b_416 != 88) |
       (!is.na(f2_s4b_420_a) & f2_s4b_420_a != 88) |
       (!is.na(f2_s4b_421_a) & f2_s4b_421_a != 88) |
       (!is.na(f2_s4b_422_a) & f2_s4b_422_a != 88) |
       (!is.na(f2_s4b_423_a) & f2_s4b_423_a != 88)) &
      (edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(vot_dur_2, cumul = F, report.nas = F)

# Vacuna contra tetanos y difteria --------------------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_424_a, cumul = F, report.nas = F)

# Indicador (menores de 5 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(tet_dif = case_when(
    f2_s4b_424_a == 1 ~ 1,
    f2_s4b_424_a == 2 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(tet_dif, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(tet_dif2 = case_when(
    f2_s4b_424_a == 1 & (edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_424_a == 2 & (edaddias < 731 & !is.na(edaddias))~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(tet_dif2, cumul = F, report.nas = F)

# Ecos Obtetricos -------------------------------------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4b_426_a, cumul = F, report.nas = F)

# Indicador (menores de 5 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(ecos_obs = case_when(
    f2_s4b_426_a == 1 ~ 1,
    f2_s4b_426_a == 2 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(ecos_obs, cumul = F, report.nas = F)

# Indicador (menores de 2 anios)
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(ecos_obs2 = case_when(
    f2_s4b_426_a == 1 &(edaddias < 731 & !is.na(edaddias)) ~ 1,
    f2_s4b_426_a == 2 &(edaddias < 731 & !is.na(edaddias)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(ecos_obs2, cumul = F, report.nas = F)

#==============================================================================#
####                           Desagregacion                                ####
#==============================================================================#

# Para establecer las etiquetas como valores y ser visibles en las funciones 
# Area
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(area = as_label(area)) 

df_f2_salud_ninez_new %>%
  freq(area, cumul = F, report.nas = F)

# Region 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(region = as_label(region)) 

df_f2_salud_ninez_new %>%
  freq(region, cumul = F, report.nas = F)

# Provincia 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(prov = as_label(prov)) 

df_f2_salud_ninez_new %>%
  freq(prov, cumul = F, report.nas = F)

# Parroquias priorizadas 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(parr_pri = as_label(parr_pri)) 

df_f2_salud_ninez_new %>%
  freq(parr_pri, cumul = F, report.nas = F)

# Sexo
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(sexo = as_label(sexo)) 

df_f2_salud_ninez_new %>%
  freq(sexo, cumul = F, report.nas = F)

# Auto-Identificacion etnica 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(etnia = as_label(etnia)) 

df_f2_salud_ninez_new %>%
  freq(etnia, cumul = F, report.nas = F)

# Quintil 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(quintil = as_label(quintil)) 

df_f2_salud_ninez_new %>%
  freq(quintil, cumul = F, report.nas = F)

# Pobreza por Ingresos 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(pobreza = as_label(pobreza)) 

df_f2_salud_ninez_new %>%
  freq(pobreza, cumul = F, report.nas = F)

# Pobreza por NBI
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>%
  mutate(nbi_1 = as_label(nbi_1)) 

df_f2_salud_ninez_new %>%
  freq(nbi_1, cumul = F, report.nas = F)

#==============================================================================#
####                       Declaracion de encuesta                          ####
#==============================================================================#

survey_design <- df_f2_salud_ninez_new %>% as_survey_design(ids = "id_upm",
                                                            strata = "estrato",
                                                            weights = "fexp")
options(survey.lonely.psu = "adjust")

#==============================================================================#
####                         Resultados ponderados                          ####
#==============================================================================#

# Para los resultados ponderados por diferentes desagregaciones reemplazar 
# respectivamente 

# Controles prenatales
# Menores de 5 anios
survey_design %>%
  srvyr_mean(c_prenatales)

survey_design %>%
  srvyr_mean_by(c_prenatales, area)

# Menores de 2 anios
survey_design %>%
  srvyr_mean(c_prenatales2)

survey_design %>%
  srvyr_mean_by(c_prenatales2, area)

# Al menos 5 controles prenatales
# Menores de 5 anios
survey_design %>%
  srvyr_prop(control5_5)

survey_design %>%
  srvyr_prop_by(control5_5, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(control5_2)

survey_design %>%
  srvyr_prop_by(control5_2, area)

# Consumo de hierro y acido folico (durante el embarazo) 
# Menores de 5 anios
survey_design %>%
  srvyr_prop(consumo_ha)

survey_design %>%
  srvyr_prop_by(consumo_ha, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(consumo_ha_2)

survey_design %>%
  srvyr_prop_by(consumo_ha_2, area)

# Examen de VIH (antes de la semana 20)
# Menores de 5 anios
survey_design %>%
  srvyr_prop(vih_ant)

survey_design %>%
  srvyr_prop_by(vih_ant, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(vih_ant_2)

survey_design %>%
  srvyr_prop_by(vih_ant_2, area)

# Examen de VIH (despues de la semana 20) 
# Menores de 5 anios
survey_design %>%
  srvyr_prop(vih_des)

survey_design %>%
  srvyr_prop_by(vih_des, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(vih_des_2)

survey_design %>%
  srvyr_prop_by(vih_des_2, area)

# Examenes de VIH (durante el embarazo)
# Menores de 5 anios
survey_design %>%
  srvyr_prop(vih_dur)

survey_design %>%
  srvyr_prop_by(vih_dur, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(vih_dur_2)

survey_design %>%
  srvyr_prop_by(vih_dur_2, area)

# Examenes de orina (antes de la semana 20)
# Menores de 5 anios
survey_design %>%
  srvyr_prop(ori_ant)

survey_design %>%
  srvyr_prop_by(ori_ant, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(ori_ant_2)

survey_design %>%
  srvyr_prop_by(ori_ant_2, area)

# Examenes de orina (despues de la semana 20)
# Menores de 5 anios
survey_design %>%
  srvyr_prop(ori_des)

survey_design %>%
  srvyr_prop_by(ori_des, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(ori_des_2)

survey_design %>%
  srvyr_prop_by(ori_des_2, area)

# Examenes de orina (durante el embarazo)
# Menores de 5 anios
survey_design %>%
  srvyr_prop(ori_dur)

survey_design %>%
  srvyr_prop_by(ori_dur, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(ori_dur_2)

survey_design %>%
  srvyr_prop_by(ori_dur_2, area)

# Examenes de TORCHs (antes de la semana 20)
# Menores de 5 anios
survey_design %>%
  srvyr_prop(torchs_ant)

survey_design %>%
  srvyr_prop_by(torchs_ant, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(torchs_ant_2)

survey_design %>%
  srvyr_prop_by(torchs_ant_2, area)

# Examenes de TORCHs (despues de la semana 20)
# Menores de 5 anios
survey_design %>%
  srvyr_prop(torchs_des)

survey_design %>%
  srvyr_prop_by(torchs_des, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(torchs_des_2)

survey_design %>%
  srvyr_prop_by(torchs_des_2, area)

# Examenes de TORCHs (durante el embarazo) 
# Menores de 5 anios
survey_design %>%
  srvyr_prop(torchs_dur)

survey_design %>%
  srvyr_prop_by(torchs_dur, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(torchs_dur_2)

survey_design %>%
  srvyr_prop_by(torchs_dur_2, area)

# Examenes de VIH, Orina y TORCHs (durante el embarazo) 
# Menores de 5 anios
survey_design %>%
  srvyr_prop(vot_dur)

survey_design %>%
  srvyr_prop_by(vot_dur, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(vot_dur_2)

survey_design %>%
  srvyr_prop_by(vot_dur_2, area)

# Vacuna contra tetanos y difteria
# Menores de 5 anios
survey_design %>%
  srvyr_prop(tet_dif)

survey_design %>%
  srvyr_prop_by(tet_dif, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(tet_dif2)

survey_design %>%
  srvyr_prop_by(tet_dif2, area)

# Ecos Obtetricos
# Menores de 5 anios
survey_design %>%
  srvyr_prop(ecos_obs)

survey_design %>%
  srvyr_prop_by(ecos_obs, area)

# Menores de 2 anios
survey_design %>%
  srvyr_prop(ecos_obs2)

survey_design %>%
  srvyr_prop_by(ecos_obs2, area)
